
c     =========================================
      logical function allowflag(x,y,t,level)
c     =========================================

c     # Indicate whether the grid point at (x,y,t) at this refinement level
c     # is allowed to be flagged for further refinement.
c
c     # This is useful if you wish to zoom in on some structure in a
c     # known location but don't want the same level of refinement elsewhere.
c     # Points are flagged only if one of the errors is greater than the
c     # corresponding tolerance.
c
c     # For example, to allow refinement of Level 1 grids everywhere but
c     # of finer grids only for  y >= 0.4:
c     # allowed(x,y,t,level) = (level.le.1 .or. y.ge.0.4d0)
c
c     # This routine is called from routine flag2refine.
c     # If Richardson error estimates are used (if tol>0) then this routine
c     # is also called from errf1.

      implicit double precision (a-h,o-z)
	

c=================Bathymetry common blocks for refinement specification===
      include 'bathcommon.i'

      common /tolerance/ depthtolerance,wavetolerance
      common /userlevels/ maxleveldeepocean, levelallowdomain
      common /generation/ iquake
c========================================================================

c======================Specify refinement levels allowed here===========
c	Note: this only allows refinement levels in a given area
c	setting allowflag = .true. for a 2nd level cell will allow it to become
c	a third level cell.  etc. etc.
c	Actual refinement will occurs based on flaging routine flag2refine.f
c===========================================================================

      allowflag=.false.

      if (level.lt.levelallowdomain) allowflag=.true.

      do m=1,mbathfiles
      	if (x.gt.xlowbath(m).and.x.lt.xhibath(m).and.
     &	    y.gt.ylowbath(m).and.y.lt.yhibath(m)) then
     		if (level.lt.ibathrefinelevel(m)) allowflag=.true.
	endif
      enddo

      do m=1,mregions
      	if (x.gt.xlowregion(m).and.x.lt.xhiregion(m).and.
     &	    y.gt.ylowregion(m).and.y.lt.yhiregion(m)) then
     		if (level.lt.levelallowregion(m)) allowflag=.true.
	endif
      enddo

      if (iquake.gt.0) then
      if (x.gt.xlowfault.and.x.lt.xhifault.and.
     &	    y.gt.ylowfault.and.y.lt.yhifault.and.
     &	    t.ge.t0fault.and.t.le.tffault) then
     		if (level.lt.mfaultrefinelevel) allowflag=.true.
      endif
      endif

      return
      end
