c     ============================================
      subroutine faultquake(maxmx,maxmy,mbc,mx,my,
     &         xlower,ylower,dx,dy,t,dt,maux,aux,
     &	       xlowbath,ylowbath,xhibath,yhibath,dxbath,dybath,
     &	       mxbath,mybath,mbath,mbathsize,i0bath,mbathorder,
     &	       mbathfiles,bath,
     &	       xlowfault,ylowfault,xhifault,yhifault,
     &	       dxfault,dyfault,dtfault,t0fault,tffault,
     &	       mxfault,myfault,mtfault,fault)
c     ============================================
c
c     This routine moves aux dynamically according to a fault model.
c     It also changes the actual bathymetry array after the dynamic
c     fault motion has ended.
c
c
      implicit double precision (a-h,o-z)

      dimension aux(1-mbc:maxmx+mbc,1-mbc:maxmy+mbc, maux)

      dimension bath(mbathsize)
      dimension fault(mxfault,myfault,mtfault)

      dimension xlowbath(mbathfiles)
      dimension ylowbath(mbathfiles)
      dimension xhibath(mbathfiles)
      dimension yhibath(mbathfiles)
      dimension dxbath(mbathfiles)
      dimension dybath(mbathfiles)

      dimension mxbath(mbathfiles)
      dimension mybath(mbathfiles)

      dimension mbathorder(mbathfiles)
      dimension i0bath(mbathfiles)
      dimension mbath(mbathfiles)

      logical bathaltered

c=====================common variable determining if bath arrays have been altered
      common /bathstate/ bathaltered

      common /cdom/ xphysupper,yphysupper,xphyslower,yphyslower,
     &                 xperdom, yperdom

c======EARTHQUAKE===========================================================
	tt = t-dt
	if (bathaltered) return
	if (tt.lt.t0fault) return

c     #change bathymetry if quaketime

        write(*,*) 'FAULTQUAKE: setting fault at time=',t

	if (tt.ge.tffault) then
	      kkm=mtfault
	      kkp=mtfault
	      tau=1.d0
	      go to 14
	endif

        do k=1,mtfault-1
	      tfaultm=t0fault+dtfault*(k-1)
	      tfaultp=tfaultm+dtfault
              if (tt.ge.tfaultm.and.tt.lt.tfaultp) then
	         kkm=k
		 kkp=k+1
		 tau=1.d0-((tt-tfaultm)/dtfault)
                 go to 14
              endif
        enddo

 14     continue

c=======loop through the computational grid row by row====================
        do j=1-mbc,my+mbc
            ycell=ylower+(j-0.5d0)*dy
            yjm=ycell-.5d0*dy
            yjp=ycell+.5d0*dy

           if (yjm.ge.ylowfault.and.yjp.le.yhifault) then
c=========sweep through the columns of the computational row================
           do i=1-mbc,mx+mbc
              xcell= xlower + (i- 0.5d0)*dx
              xim= xcell - .5d0*dx
              xip= xcell + .5d0*dx

              if (xim.ge.xlowfault.and.xip.le.xhifault) then
c==========alter aux(i,j,1) if it is in the fault region=====================

c==========first reset the auxillary value since it was previously changed===

                 auxij=0.d0
                 call setaux(1,1,0,1,1,xim,yjm,dx,dy,1,auxij)
                 aux(i,j,1)=auxij

c=============================================================================

c==================dynamically alter the bathymetry to the interpolated value=
		 dauxijm=0.d0
                 call bathinterp(dauxijm,xim,xcell,xip,yjm,ycell,yjp,
     &              xlowfault,ylowfault,dxfault,dyfault,
     &		    mxfault,myfault,fault(1,1,kkm),.true.)

     		  dauxijp=0.d0
                  call bathinterp(dauxijp,xim,xcell,xip,yjm,ycell,yjp,
     &              xlowfault,ylowfault,dxfault,dyfault,
     &		    mxfault,myfault,fault(1,1,kkp),.true.)

                 aux(i,j,1)=aux(i,j,1)+tau*dauxijm+(1.d0-tau)*dauxijp

              endif
           enddo
           endif
         enddo
c============= end of altering topography dynamically========================


c=================if the aux cell is outside the physical domain, boundary conditions must be reset==
	 if (xlowfault.lt.xphyslower.and.
     &      xlower+(0.5d0-mbc)*dx.lt.xphyslower) then
            do j=1-mbc,my+mbc
	       ycell=ylower+(j-0.5d0)*dy
               yjm=ycell-.5d0*dy
               yjp=ycell+.5d0*dy

	       xcell= xlower + (1- 0.5d0)*dx
               xim= xcell - .5d0*dx
               xip= xcell + .5d0*dx
               if ((xim.ge.xlowfault.and.xip.le.xhifault).and.
     &	              (yjm.ge.ylowfault.and.yjp.le.yhifault)) then

		   do i=1-mbc,0
		      aux(i,j,1)=aux(1,j,1)
		   enddo
	       endif
	    enddo
	  endif

	  if (xhifault.gt.xphysupper.and.
     &      xlower+(mx+mbc-0.5d0)*dx.gt.xphysupper) then
            do j=1-mbc,my+mbc
	       ycell=ylower+(j-0.5d0)*dy
               yjm=ycell-.5d0*dy
               yjp=ycell+.5d0*dy

	       xcell= xlower + (mx-0.5d0)*dx
               xim= xcell - .5d0*dx
               xip= xcell + .5d0*dx
               if ((xim.ge.xlowfault.and.xip.le.xhifault).and.
     &	              (yjm.ge.ylowfault.and.yjp.le.yhifault)) then

		   do i=mx+1,mx+mbc
		      aux(i,j,1)=aux(mx,j,1)
		   enddo
	       endif
	    enddo
	  endif

	  if (ylowfault.lt.yphyslower.and.
     &	     ylower+(.5d0-mbc)*dy.lt.yphyslower) then
     	     do i=1-mbc,mx+mbc
	       ycell=ylower+(1-0.5d0)*dy
               yjm=ycell-.5d0*dy
               yjp=ycell+.5d0*dy

	       xcell= xlower + (i- 0.5d0)*dx
               xim= xcell - .5d0*dx
               xip= xcell + .5d0*dx

	       if ((xim.ge.xlowfault.and.xip.le.xhifault).and.
     &	              (yjm.ge.ylowfault.and.yjp.le.yhifault)) then

		   do j=1-mbc,0
		      aux(i,j,1)=aux(i,1,1)
		   enddo
	       endif
	    enddo
	  endif

	  if (yhifault.gt.yphysupper.and.
     &	     ylower+(my+mbc-0.5d0)*dy.gt.yphysupper) then
     	     do i=1-mbc,mx+mbc
	       ycell=ylower+(my-0.5d0)*dy
               yjm=ycell-.5d0*dy
               yjp=ycell+.5d0*dy

	       xcell= xlower + (i- 0.5d0)*dx
               xim= xcell - .5d0*dx
               xip= xcell + .5d0*dx

	       if ((xim.ge.xlowfault.and.xip.le.xhifault).and.
     &	              (yjm.ge.ylowfault.and.yjp.le.yhifault)) then

		   do j=my+1,my+mbc
		      aux(i,j,1)=aux(i,my,1)
		   enddo
	       endif
	    enddo
	  endif
c===========================B.C.'s reset========================================



c============= statically change bathymetry array for next call to setaux====
	if (tt-dt.gt.tffault) then
          bathaltered=.true.
	  write(*,*) 'FAULTQUAKE: Altering bathymetry arrays at t=',t
	  write(*,*) 'FAULTQUAKE: Fault Motion Complete'
	  do m=1,mbathfiles
	    if (xlowbath(m).le.xhifault.and.xhibath(m).ge.xlowfault
     &		.and.ylowbath(m).le.yhifault.and.
     &					yhibath(m).ge.ylowfault) then

            do ib=1,mxbath(m)
              xcell=xlowbath(m) + (ib-.5d0)*dxbath(m)
              xim=xlowbath(m) + (ib-1.d0)*dxbath(m)
              xip=xlowbath(m) + ib*dxbath(m)

            if (xim.ge.xlowfault.and.xip.le.xhifault) then
               do jb=1,mybath(m)
             	ycell=ylowbath(m) + (jb-.5d0)*dybath(m)
             	yjm=ylowbath(m) + (jb-1.d0)*dybath(m)
             	yjp=ylowbath(m) + jb*dybath(m)

                if (yjm.ge.ylowfault.and.yjp.le.yhifault) then
                   zbathij=0.d0
                   call bathinterp(zbathij,xim,xcell,xip,yjm,ycell,yjp,
     &              xlowfault,ylowfault,dxfault,dyfault,
     &		    mxfault,myfault,fault(1,1,mtfault),.true.)
     		    jbr=mybath(m)-jb+1
                    ij=i0bath(m) + (jbr-1)*mxbath(m) +ib -1
		    bath(ij)=bath(ij)+zbathij
                endif
               enddo
            endif
           enddo
	  endif
	  enddo
        endif
c=================================================================================


      return
      end
