c=========================================================================
      subroutine setprob
c=========================================================================

      implicit double precision (a-h,o-z)

      logical bathaltered

      include "bathcommon.i"

c=====================Parameters===========================================
      common /comrp/ grav
      common /tolerance/ depthtolerance,wavetolerance
      common /userlevels/ maxleveldeepocean, levelallowdomain
      common /generation/ iquake
      common /earth/ Rearth,R1,R2,pi
      common /manningcoef/ coeff
      common /nearshore/ shallowdepth
      common /bathstate/ bathaltered

      common /cdom/ xupper,yupper,xlower,ylower,
     &                 xperdom, yperdom

      common /latlongrid/ mcapacity,mauxiliary
c==========================================================================

c     #Earth Radius params needed for latitude longitude grid to physical manifold
        R1=6357.d3
        R2=6378.d3
	Rearth=.5d0*(R1+R2)
	pi=3.14159265359d0

c	#read the initial time from amr2ez.data, for use when restarting
	open(unit=9,file='amr2ez.data',status='old',form='formatted')
	do junk=1,22
	   read(9,*)
	enddo
	read(9,*) mcapacity
	read(9,*) mauxiliary
	do junk=1,8
	   read(9,*)
	enddo
	read(9,*) tstart
	close(unit=9)
c     # read user parameters from setprob.data

      open(unit=7,file='setprob.data',status='old',form='formatted')
         read(7,*) grav
         read(7,*) depthtolerance
	 read(7,*) shallowdepth
	 read(7,*) wavetolerance
	 read(7,*) coeff
	 read(7,*) maxleveldeepocean
	 read(7,*) levelallowdomain
	 read(7,*) iquake
	 read(7,*) mfaultrefinelevel
	 read(7,*) faultfname
	 read(7,*) mbathfiles
      	 if (mbathfiles.gt.maxbathfiles) then
	  write(*,*) 'SETPROB: ERROR mbathfiles > maxbathfiles'
	  write(*,*) 'Decrease the number of bathymetry files or'
          write(*,*) 'Increase maxbathfiles in bathcommon.i'
	  stop
         endif
	 read(7,*) (ibathrefinelevel(i),i=1,mbathfiles)
         do i=1,mbathfiles
	  read(7,*) bathfname(i)
         enddo

	 read(7,*) mregions
	 if (mregions.gt.maxregions) then
	   write(*,*) 'SETPROB: ERROR mregions > maxregions'
	   write(*,*) 'Decrease the number of regions or'
           write(*,*) 'Increase maxregions in bathcommon.i'
	  stop
	 endif
	 read(7,*) (levelallowregion(i),i=1,mregions)
	 do i=1,mregions
	   read(7,*) xlowregion(i),xhiregion(i),
     &		ylowregion(i),yhiregion(i)
         enddo

      close(7)

      write(*,*) 'SETPROB: setprob.data  input complete:'
      write(*,*) 'tstart',tstart
      write(*,*) 'gravity:',grav
      write(*,*) 'depthtolerance:',depthtolerance
      write(*,*) 'shallowdepth:', shallowdepth
      write(*,*) 'wavetolerance:',wavetolerance
      write(*,*) 'Manning coefficient:',coeff
      write(*,*) 'maxleveldeepocean',maxleveldeepocean
      write(*,*) 'levelallowdomain',levelallowdomain
      write(*,*) 'Number of bathymetry files:',mbathfiles
      write(*,*) 'Refinement levels allowed in bathymetry regions:',
     &      (ibathrefinelevel(i),i=1,mbathfiles)
      write(*,*) 'iquake', iquake
      write(*,*) 'Minimum refinement level enforced in fault region:',
     &		mfaultrefinelevel
      write(*,*) 'mregions',mregions
      write(*,*) 'Refinement levels allowed in regions:',
     &      (levelallowregion(i),i=1,mregions)

c=================== READ BATHYMETRY==================================
c============# file specification and format=======================
c Bathymetry is in numerical ascii txt file specified in setprob.data
c file should be in standard GIS format: 3 columns: lon,lat,height(m)
c advancing northwest to northeast then from north to south. Values should be
c uniformly spaced in latitude longitude space.
c For other formats modify readbath.f and newbath.f
c
c Finest value of bathymetry in a given region will be used for computation
c=====================================================================
	if (mbathfiles.gt.0) then
	ibath=0
	do i=1,mbathfiles
	   call readbath(mxbath(i),mybath(i),dxbath(i),dybath(i),
     &		xlowbath(i),xhibath(i),ylowbath(i),yhibath(i),
     &		maxbathsize,ibath,bathwork,bathfname(i))
		mbath(i)=mxbath(i)*mybath(i)
	enddo
	mbathsize=ibath
	if (mbathsize.gt.maxbathsize) then
	    write(*,*) 'SETPROB: overflow error'
	    write(*,*) 'Recomplile after increasing maxbathsize to', mbathsize
	    write(*,*) 'In bathcommon.i'
	    Stop
	else
	    write(*,*) 'SETPROB: bathymetry space allocated:',maxbathsize
	    write(*,*) 'SETPROB: bathymetry space used:',mbathsize
	endif

c     parameters for partitioning bathymetry array
	i0bath(1)=1
	if (mbathfiles.gt.1) then
	  do i=2,mbathfiles
	    i0bath(i)=i0bath(i-1) + mbath(i-1)
	  enddo
	endif
c    bathymetry order...This determines which order to process bathymetry
c    The finest bathymetry will be given priority in any region
	do i=1,mbathfiles
	  smallerthan=0
	  do j=1,mbathfiles
	     sizei=dxbath(i)*dybath(i)
             sizej=dxbath(j)*dybath(j)
	     if (sizei.lt.sizej) smallerthan=smallerthan+1
c	    if two files have the same resolution, order is arbitrarily chosen
             if (sizei.eq.sizej.and.j.lt.i) smallerthan=smallerthan+1
          enddo
          mbathorder(i)=mbathfiles-smallerthan
        enddo
	endif
c=======================================================================

c=============== FAULT RUPTURE MODEL=====================================
c       If iquake=2 then a dynamic fault model file will be used to generate
c	the tsunami.
c
c       The fault model file should be a numeric ascii text file, with 4 columns,
c	time,longitude,latitude,vertical displacement(m).

c	Longitude and latitude advance in the standard GIS way (see above).
c       Time column advances most slowly.
c	Time must be after starting computational time, which should be t=0.

c	For using a single initial displacement of the surface, set iquake=1
c	in setprob.data and provide a file with three columns
c	longitude,latitude,vertical displacement(m) of the surface in GIS way.
	if (iquake.gt.0) then
	ifault=0
           call readfault(iquake,mxfault,myfault,mtfault,
     &	     dxfault,dyfault,dtfault,
     &	     xlowfault,xhifault,ylowfault,yhifault,
     &	     t0fault,tffault,mfaultsize,ifault,faultwork,faultfname)
             mfault=mxfault*myfault*mtfault

c===================Check Fault Memory=============================
	if (mfault.gt.maxfaultsize) then
	    write(*,*) 'SETPROB: overflow error'
	    write(*,*) 'Increase maxfaultsize to', mfault
	    write(*,*) 'in bathcommon.i then recompile'
	    Stop
	else
	    write(*,*) 'SETPROB: fault bathymetry space allocated:'
     &		,maxfaultsize
	    write(*,*) 'SETPROB: fault bathymetry space used:',mfault
	endif
c===================================================================
	endif

c==========Check to see if bathymetry is========================
c==============consistent with domain set in amr2ez.data========
c=========May not catch all errors==============================

	if (mbathfiles.gt.0) then
	xbmin=360.d0
	xbmax= -180.d0
	ybmin=90.d0
	ybmax=-90.d0
	do i=1,mbathfiles
	   xbmin=min(xbmin,xlowbath(i))
	   xbmax=max(xbmax,xhibath(i))
	   ybmin=min(ybmin,ylowbath(i))
	   ybmax=max(ybmax,yhibath(i))
	enddo

	if ((xbmin.gt.xlower.or.xbmax.lt.xupper).or.
     &		(ybmin.gt.ylower.or.ybmax.lt.yupper)) then
	   write(*,*) 'SETPROB ERROR: Bathymetry does not cover domain'
	   write(*,*) 'COMPUTATIONAL: xlower,xupper,ylower,yupper:'
	   write(*,*) xlower,xupper,ylower,yupper
	   write(*,*) 'BATHYMETRY: xlower,xupper,ylower,yupper:'
	   write(*,*) xbmin,xbmax,ybmin,ybmax
	   stop
	endif
	endif
c=======================================================================================



c==============Fix Bathymetry for a Restart================================================

c     #bathaltered is ordinarily initialized as .false.-  this variable indicates when bathymetry
c	arrays have been altered based on a fault model.  For restarts after the end of a quake
c	the bathymetry arrays are altered here to match the resulting bathymetry after the quake.
	if (iquake.gt.0) then
	if (tstart.le.tffault.and.iquake.eq.2) then
		bathaltered=.false.

c============= statically change bathymetry array for next call to setaux====
	elseif (tstart.gt.tffault.and.iquake.eq.2) then
          	bathaltered=.true.
	  write(*,*) 'SETPROB: Altering bathymetry arrays at t=',tstart
	  do m=1,mbathfiles
	    if (xlowbath(m).le.xhifault.and.xhibath(m).ge.xlowfault
     &		.and.ylowbath(m).le.yhifault.and.
     &					yhibath(m).ge.ylowfault) then

            do ib=1,mxbath(m)
              xcell=xlowbath(m) + (ib-.5d0)*dxbath(m)
              xim=xlowbath(m) + (ib-1.d0)*dxbath(m)
              xip=xlowbath(m) + ib*dxbath(m)

            if (xim.ge.xlowfault.and.xip.le.xhifault) then
               do jb=1,mybath(m)
             	ycell=ylowbath(m) + (jb-.5d0)*dybath(m)
             	yjm=ylowbath(m) + (jb-1.d0)*dybath(m)
             	yjp=ylowbath(m) + jb*dybath(m)

                if (yjm.ge.ylowfault.and.yjp.le.yhifault) then
                   zbathij=0.d0
		   ijfault=(mtfault-1)*mxfault*myfault+1
                   call bathinterp(zbathij,xim,xcell,xip,yjm,ycell,yjp,
     &              xlowfault,ylowfault,dxfault,dyfault,
     &		    mxfault,myfault,faultwork(ijfault),.true.)
     		    jbr=mybath(m)-jb+1
                    ij=i0bath(m) + (jbr-1)*mxbath(m) +ib -1
		    bathwork(ij)=bathwork(ij)+zbathij

                endif
               enddo
            endif
           enddo
	  endif
	  enddo
        endif
	endif


      return
      end
